==> pupy-2.16.6.tar.gz: pupy-2.16.6/readme.md <==
# PUPY ~ Pretty Useful Python

This package (pupy) is full of Pretty Useful Python.

## These things

[![Build Status](https://travis-ci.org/jessekrubin/pupy.svg?branch=master)](https://travis-ci.org/jessekrubin/pupy) 
[![Wheel](https://img.shields.io/pypi/wheel/pupy.svg)](https://img.shields.io/pypi/wheel/pupy.svg) 
[![Version](https://img.shields.io/pypi/v/pupy.svg)](https://img.shields.io/pypi/v/pupy.svg) 
[![py_versions](https://img.shields.io/pypi/pyversions/pupy.svg)](https://img.shields.io/pypi/pyversions/pupy.svg) 
 

## Installin'

Installing is EZPZ...

    pip install pupy

### Want more???

Pupy has a few optional dependenies for reading and writing files which can be installed with the following command:
    
    pip install pupy[io]

Or you can pick and choose...

If you plan on using Jason you can install `ujson` for a speed boost *(if you wanna go fast; pupy uses the python-stdlib json if you wanna go slow)*...

    pip install ujson 

But wait theres more! Pupy has several optional dependencies for savings and loads which you can install with...
    
    pip install ruamel.yaml  # If ya mel in your spare time
    pip install msgpack  # If you wanna pack messages
    pip install toml  # toml (aka 'that other markup language'(?))
    pip install aiofiles  # if you wanna do async stuff

## Testimonials

*'Ahead of the curve.' -Haley who goes to Harvard*

*'huh?' -Tim Apple*

*'If I were stranded on a dessert island and had to pick between having a copy pupy or a thing of water I would pick the water, but if I didn't have to pick it wouldn't hurt to have.' -Ryan of the fro with his fro*

*'I don't use python.' -KirstenKirsten Chief Evernote Officer*

*'I can't say google wouldn't not go down if it weren't for pupy.' -Ben W from the g-suite*

*'A literary masterpiece on par with my second greatest work finite jest.' -Bananas Foster Wallace*

*'Best place for python savings and loads in the tri-content area.' -Genghis Khan*

==> pupy-2.19.0.tar.gz: pupy-2.19.0/readme.md <==
# PUPY ~ Pretty Useful Python

This package (pupy) is full of Pretty Useful Python.

## These things

[![Build Status](https://travis-ci.org/jessekrubin/pupy.svg?branch=master)](https://travis-ci.org/jessekrubin/pupy) 
[![Wheel](https://img.shields.io/pypi/wheel/pupy.svg)](https://img.shields.io/pypi/wheel/pupy.svg) 
[![Version](https://img.shields.io/pypi/v/pupy.svg)](https://img.shields.io/pypi/v/pupy.svg) 
[![py_versions](https://img.shields.io/pypi/pyversions/pupy.svg)](https://img.shields.io/pypi/pyversions/pupy.svg) 
 

## Installin'

Installing is EZPZ...

    pip install pupy

### Want more???

Pupy has a few optional dependenies for reading and writing files which can be installed with the following command:
    
    pip install pupy[io]

Or you can pick and choose...

If you plan on using Jason you can install `ujson` 

    pip install ujson 
    
or `rapidjson` for a speed boost 

    pip install python-rapidjson

and if pupy can't find either it'll fall back on the python-stdlib json thing.

But wait theres more! Pupy has several optional dependencies for savings and loads which you can install with...
    
    pip install ruamel.yaml  # If ya mel in your spare time
    pip install msgpack  # If you wanna pack messages
    pip install toml  # toml (aka 'that other markup language'(?))
    pip install aiofiles  # if you wanna do async stuff

## Testimonials

*'Ahead of the curve.' -Haley who goes to Harvard*

*'huh?' -Tim Apple*

*'If I were stranded on a dessert island and had to pick between having a copy pupy or a thing of water I would pick the water, but if I didn't have to pick it wouldn't hurt to have.' -Ryan of the fro with his fro*

*'I don't use python.' -KirstenKirsten Chief Evernote Officer*

*'I can't say google wouldn't not go down if it weren't for pupy.' -Ben W from the g-suite*

*'A literary masterpiece on par with my second greatest work finite jest.' -Bananas Foster Wallace*

*'Best place for python savings and loads in the tri-content area.' -Genghis Khan*
